import { CSSProperties, InjectionKey, Ref } from 'vue';
import { AuthProviders, BaseAppearance, BaseAuth, I18nVariables, SocialLayout, ViewType } from '@supabase/auth-ui-shared';
import { SupabaseClient } from '@supabase/supabase-js';
export interface Appearance extends BaseAppearance {
    style?: {
        anchor?: CSSProperties;
        button?: CSSProperties;
        container?: CSSProperties;
        divider?: CSSProperties;
        input?: CSSProperties;
        label?: CSSProperties;
        loader?: CSSProperties;
        message?: CSSProperties;
    };
}
export interface Auth extends BaseAuth {
    appearance?: BaseAppearance;
}
export interface AuthProps {
    supabaseClient: SupabaseClient;
    socialLayout?: SocialLayout;
    providers?: AuthProviders;
    view?: ViewType;
    redirectTo?: undefined | string;
    onlyThirdPartyProviders?: boolean;
    magicLink?: boolean;
    showLinks?: boolean;
    /**
     * This will toggle on the dark variation of the theme
     */
    dark?: boolean;
    /**
     * Override the labels and button text
     */
    localization?: {
        lang?: 'en' | 'zh';
        variables?: I18nVariables;
    };
    appearance?: BaseAppearance;
    theme?: 'default' | string;
}
export declare type AuthProvider = 'google' | 'facebook' | 'twitter' | 'apple' | 'github' | 'gitlab' | 'bitbucket' | 'discord' | 'azure' | 'keycloak' | 'linkedin' | 'notion' | 'slack' | 'spotify' | 'twitch' | 'workos';
export interface AuthViewInjection {
    authView: Ref<ViewType>;
    setAuthView: (view: ViewType) => void;
}
export declare const AuthViewKey: InjectionKey<AuthViewInjection>;
